@@ -1,4 +1,3 @@
-import os
 import shutil
 
 from moodle_dl.utils import cutie
@@ -46,7 +45,6 @@ class ConfigService:
         self._select_should_download_links_in_descriptions()
         self._select_should_download_databases()
         self._select_should_download_linked_files()
-        self._select_should_load_default_filename_character_map()
 
     def _select_courses_to_download(self, courses: [Course]):
         """
@@ -336,59 +334,6 @@ class ConfigService:
 
         self.config_helper.set_property('download_linked_files', download_linked_files)
 
-    def _select_should_load_default_filename_character_map(self):
-        """
-        Asks the user if the default filename character map should be loaded
-        """
-        filename_character_map = self.config_helper.get_filename_character_map()
-
-        if os.name != 'nt':
-            self.section_seperator()
-
-            Log.info(
-                'On Windows many characters are forbidden in filenames and paths, if you want, these characters can be'
-                + ' automatically removed from filenames.'
-            )
-
-            Log.warning('If you want to view the downloaded files on Windows this is important!')
-
-            print('Current filename character map: {}'.format(filename_character_map))
-            Log.special('Do you want to load the default filename character map for Windows?')
-
-            choices = [
-                'No, leave it as it was.',
-                'No, load the default linux filename character map.',
-                'Yes, load the default windows filename character map.',
-            ]
-
-            print('[Confirm your selection with the Enter key]')
-            print('')
-
-            selected_map = cutie.select(options=choices)
-
-            if selected_map == 0:
-                return
-            elif selected_map == 1:
-                self.config_helper.set_default_filename_character_map(False)
-            elif selected_map == 2:
-                self.config_helper.set_default_filename_character_map(True)
-        else:
-            if filename_character_map != ConfigHelper.windows_map:
-
-                self.section_seperator()
-                Log.warning(
-                    'Warning: Your current filename character map does not match the standard Windows'
-                    + ' filename character map!'
-                )
-                print('Current filename character map: {}'.format(filename_character_map))
-                load_default_map = cutie.prompt_yes_or_no(
-                    Log.special_str('Do you want to load the default filename character map for Windows?'),
-                    default_is_yes=False,
-                )
-                if load_default_map:
-                    self.config_helper.set_default_filename_character_map(True)
-
     def section_seperator(self):
-        """Print a seperator line.
-        """
+        """Print a seperator line."""
         print('\n' + '-' * shutil.get_terminal_size().columns + '\n')
