@@ -3,6 +3,7 @@ import ssl
 import sys
 import time
 import shutil
+import logging
 import threading
 from queue import Queue
 import certifi
@@ -25,6 +26,8 @@ class DownloadService:
     and errors.
     """
 
+    thread_count = 5
+
     def __init__(
         self, courses: [Course], moodle_service: MoodleService, storage_path: str, skip_cert_verify: bool = False
     ):
@@ -38,7 +41,6 @@ class DownloadService:
         """
 
         # How much threads should be created
-        DownloadService.thread_count = 5
         if 'pydevd' in sys.modules:
             # if debugging only one thread should be started
             DownloadService.thread_count = 1
@@ -103,6 +105,8 @@ class DownloadService:
 
                     self.total_files += 1
 
+        logging.debug('Queue contains %s URLTargets', self.total_files)
+
     @staticmethod
     def gen_path(storage_path: str, course: Course, file: File):
         """
