@@ -109,32 +109,57 @@ class URLTarget(object):
             except FileExistsError:
                 pass
 
+    def _get_path_of_non_existent_file(self, wish_path: str) -> str:
+        """Generates a path to a non existing file, based on a wish path
+
+        Args:
+            wish_path (str): the ideal path that is wished
+
+        Returns:
+            str: a path to a non existing file
+        """
+        new_path = wish_path
+
+        count = 0
+        content_filename = os.path.basename(wish_path)
+        destination = os.path.dirname(wish_path)
+        filename, file_extension = os.path.splitext(content_filename)
+
+        while os.path.exists(new_path):
+            count += 1
+
+            new_filename = '%s_%02d%s' % (filename, count, file_extension)
+
+            new_path = str(Path(destination) / new_filename)
+
+        # Working around MAX_PATH limitation on Windows (see
+        # http://msdn.microsoft.com/en-us/library/windows/desktop/aa365247(v=vs.85).aspx)
+        if os.name == 'nt':
+            absfilepath = os.path.abspath(new_path)
+            if len(absfilepath) > 259:
+                new_path = '\\\\?\\' + absfilepath
+
+        return new_path
+
     def _rename_if_exists(self, path: str) -> str:
         """
         Rename a file name until no file with the same name exists.
         @param path: The path to the file to be renamed.
         @return: A path to a file that does not yet exist.
         """
-        count = 1
-        new_path = path
-        content_filename = os.path.basename(path)
-        destination = os.path.dirname(path)
 
-        # this is some kind of raise condition
-        # Even though it should hardly ever happen,
-        # it is possible that threads try to create the same file
+        # lock because of raise condition
         self.fs_lock.acquire()
-        while os.path.exists(new_path):
-            count += 1
+        new_path = self._get_path_of_non_existent_file(path)
 
-            filename, file_extension = os.path.splitext(content_filename)
+        logging.debug('T%s - Seting up target file: "%s"', self.thread_id, new_path)
+        try:
+            open(new_path, 'a').close()
+        except Exception as e:
+            self.fs_lock.release()
+            logging.error('T%s - Failed seting up target file: "%s"', self.thread_id, new_path)
+            raise e
 
-            new_filename = '%s_%02d%s' % (filename, count, file_extension)
-
-            new_path = str(Path(destination) / new_filename)
-
-        logging.debug('T%s - Set up target file: "%s"', self.thread_id, new_path)
-        Path(new_path).touch()
         self.fs_lock.release()
 
         return new_path
@@ -152,6 +177,8 @@ class URLTarget(object):
         if not os.path.exists(old_path):
             return False
 
+        logging.debug('T%s - Renaming old file', self.thread_id)
+
         count = 1
         content_filename = os.path.basename(old_path)
         filename, file_extension = os.path.splitext(content_filename)
@@ -160,23 +187,15 @@ class URLTarget(object):
         destination = os.path.dirname(old_path)
         new_path = str(Path(destination) / content_filename)
 
-        # this is some kind of raise condition
-        # Even though it should hardly ever happen,
-        # it is possible that threads try to create the same file
+        # lock because of raise condition
         self.fs_lock.acquire()
-        while os.path.exists(new_path):
-            count += 1
-
-            filename, file_extension = os.path.splitext(content_filename)
-
-            new_filename = '%s_%02d%s' % (filename, count, file_extension)
-
-            new_path = str(Path(destination) / new_filename)
+        new_path = self._get_path_of_non_existent_file(new_path)
 
         try:
             shutil.move(old_path, new_path)
             self.file.old_file.saved_to = new_path
         except Exception:
+            logging.warning('T%s - Failed to renaming old file "%s" to "%s"', self.thread_id, old_path, new_path)
             self.fs_lock.release()
             return False
 
@@ -274,43 +293,38 @@ class URLTarget(object):
         @params tmp_file: Is a path + the basename
                           (without the extension) of the tmp_file
         """
-        destination = os.path.dirname(tmp_file)
-        content_filename = os.path.basename(tmp_file)
+        lookup_dir = os.path.dirname(tmp_file)
+        tmp_filename = os.path.basename(tmp_file)
 
-        logging.debug('T%s - Renaming "%s" to "%s"', self.thread_id, content_filename, self.filename)
-        for filename in os.listdir(destination):
-            if filename.startswith(content_filename + '.'):
-                one_tmp_file = os.path.join(destination, filename)
+        logging.debug('T%s - Renaming "%s" to "%s"', self.thread_id, tmp_filename, self.filename)
+        for found_filename in os.listdir(lookup_dir):
+            if found_filename.startswith(tmp_filename + '.'):
+                one_tmp_file = os.path.join(lookup_dir, found_filename)
 
-                content_filename = os.path.basename(one_tmp_file)
-                filename, file_extension = os.path.splitext(content_filename)
+                found_filename_base, found_file_extension = os.path.splitext(found_filename)
 
-                new_path = str(Path(self.destination) / self.filename) + file_extension
-
-                count = 1
-                content_filename = os.path.basename(new_path)
-                destination = os.path.dirname(new_path)
+                new_filename = self.filename + found_file_extension
+                new_path = str(Path(self.destination) / new_filename)
 
+                # lock because of raise condition
                 self.fs_lock.acquire()
-                while os.path.exists(new_path):
-                    count += 1
-
-                    filename, file_extension = os.path.splitext(content_filename)
-
-                    new_filename = '%s_%02d%s' % (filename, count, file_extension)
-
-                    new_path = str(Path(destination) / new_filename)
+                new_path = self._get_path_of_non_existent_file(new_path)
 
                 self.file.saved_to = new_path
                 try:
+                    logging.debug('T%s - Moved "%s" to "%s"', self.thread_id, found_filename, new_filename)
                     shutil.move(one_tmp_file, self.file.saved_to)
                 except Exception as e:
                     logging.warning(
-                        'T%s - Failed to move the temporary video file %s!  Error: %s', self.thread_id, one_tmp_file, e
+                        'T%s - Failed to move the temporary video file %s to %s!  Error: %s',
+                        self.thread_id,
+                        found_filename,
+                        new_filename,
+                        e,
                     )
                 self.fs_lock.release()
 
-                self.file.time_stamp = int(time.time())
+        self.file.time_stamp = int(time.time())
 
     def try_download_link(
         self, add_token: bool = False, delete_if_successful: bool = False, use_cookies: bool = False
@@ -330,7 +344,7 @@ class URLTarget(object):
         """
 
         urlToDownload = self.file.content_fileurl
-        logging.debug('T%s - Try to download linked file %s.', self.thread_id, urlToDownload)
+        logging.debug('T%s - Try to download linked file %s', self.thread_id, urlToDownload)
 
         if add_token:
             urlToDownload = self._add_token_to_url(self.file.content_fileurl)
@@ -340,7 +354,21 @@ class URLTarget(object):
             cookies_path = self.options.get('cookies_path', None)
             if cookies_path is None:
                 self.success = False
-                raise ValueError('Moodle Cookies are missing.')
+                raise ValueError(
+                    'Moodle Cookies are missing. Run `moodle-dl -nt` to set a privatetoken for cookie generation (If necessary additionally `-sso`)'
+                )
+
+        if delete_if_successful:
+            # if temporary file is not needed delete it as soon as possible
+            try:
+                os.remove(self.file.saved_to)
+            except Exception as e:
+                logging.warning(
+                    'T%s - Could not delete %s before download is started. Error: %s',
+                    self.thread_id,
+                    self.file.saved_to,
+                    e,
+                )
 
         isHTML = False
         new_filename = ""
@@ -382,17 +410,6 @@ class URLTarget(object):
                         # return False
                         pass
                     else:
-                        if delete_if_successful:
-                            try:
-                                os.remove(self.file.saved_to)
-                            except Exception as e:
-                                logging.warning(
-                                    'T%s - Could not delete %s after youtube-dl was successful. Error: %s',
-                                    self.thread_id,
-                                    self.file.saved_to,
-                                    e,
-                                )
-                                self.log_exception_extras(e)
                         self.move_tmp_file(tmp_file)
                         self.success = True
                         return True
@@ -400,6 +417,8 @@ class URLTarget(object):
                     # return False
                     pass
 
+        logging.debug('T%s - Downloading file directly', self.thread_id)
+
         # generate file extension for modules names
         new_name, new_extension = os.path.splitext(new_filename)
         if new_extension == '' and isHTML:
@@ -413,17 +432,6 @@ class URLTarget(object):
         if old_extension != new_extension:
             self.filename = self.filename + new_extension
 
-        if delete_if_successful:
-            try:
-                os.remove(self.file.saved_to)
-            except Exception:
-                logging.warning(
-                    'T%s - Could not delete %s before download is started. Error: %s',
-                    self.thread_id,
-                    self.file.saved_to,
-                    e,
-                )
-
         self.set_path(True)
 
         if total_bytes_estimate != -1:
@@ -528,6 +536,7 @@ class URLTarget(object):
         """
         Creates a Description file
         """
+        logging.debug('T%s - Creating a description file', self.thread_id)
         description = open(self.file.saved_to, 'w+', encoding='utf-8')
         to_save = ""
         if self.file.text_content is not None:
@@ -541,14 +550,13 @@ class URLTarget(object):
         description.close()
 
         if to_save == '':
-            logging.debug('T%s - Remove target file because description file would be empty.', self.thread_id)
+            logging.debug('T%s - Remove target file because description file would be empty', self.thread_id)
             os.remove(self.file.saved_to)
 
             self.file.time_stamp = int(time.time())
 
             self.success = True
         else:
-            logging.debug('T%s - Creating a description file', self.thread_id)
             self.file.time_stamp = int(time.time())
 
             self.success = True
@@ -566,7 +574,7 @@ class URLTarget(object):
         if not os.path.exists(old_path):
             return False
 
-        logging.debug('T%s - Moving old file "%s" to new target location.', self.thread_id, old_path)
+        logging.debug('T%s - Moving old file "%s" to new target location', self.thread_id, old_path)
         try:
             shutil.move(old_path, self.file.saved_to)
             self.file.time_stamp = int(time.time())
@@ -574,6 +582,7 @@ class URLTarget(object):
             return True
         except FileExistsError:
             # On Windows, the temporary file must be deleted first.
+            # lock because of raise condition
             self.fs_lock.acquire()
 
             try:
@@ -586,12 +595,10 @@ class URLTarget(object):
                 return True
             except Exception as e:
                 logging.warning('T%s - Moving the old file %s failed!  Error: %s', self.thread_id, old_path, e)
-                self.log_exception_extras(e)
 
             self.fs_lock.release()
         except Exception:
             logging.warning('T%s - Moving the old file %s failed unexpectedly!  Error: %s', self.thread_id, old_path, e)
-            self.log_exception_extras(e)
 
         return False
 
@@ -655,7 +662,7 @@ class URLTarget(object):
                 return self.success
 
             url_to_download = self.file.content_fileurl
-            logging.debug('T%s - Downloading %s.', self.thread_id, url_to_download)
+            logging.debug('T%s - Downloading %s', self.thread_id, url_to_download)
 
             if add_token:
                 url_to_download = self._add_token_to_url(self.file.content_fileurl)
@@ -681,7 +688,6 @@ class URLTarget(object):
                 pass
 
             logging.error('T%s - Error while trying to download file: %s', self.thread_id, self)
-            self.log_exception_extras(e)
 
             if self.downloaded == 0 and filesize == 0:
                 try:
@@ -695,7 +701,6 @@ class URLTarget(object):
                         self.file.saved_to,
                         e,
                     )
-                    self.log_exception_extras(e)
             else:
                 # Subtract the already downloaded content in case of an error.
                 self.thread_report[self.thread_id]['total'] -= self.downloaded
@@ -781,18 +786,6 @@ class URLTarget(object):
         else:
             return '%02d:%02d:%02d' % (hours, mins, secs)
 
-    def log_exception_extras(self, exc):
-        """Log the extras of an exception object
-
-        Args:
-            exc (Exception): Exception that has occurred
-        """
-        if hasattr(exc, 'winerror'):
-            logging.debug("Exception winerror: %s", exc.winerror)
-
-        if hasattr(exc, 'winerror'):
-            logging.debug("Exception errno: %s", exc.errno)
-
     def __str__(self):
         # URLTarget to string
         return 'URLTarget (%(file)s, %(course)s, %(success)s, Error: %(error)s)' % {
